/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AuthenticatorConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#id Authenticator#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * A human-readable string that identifies the Authenticator
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#key Authenticator#key}
    */
    readonly key: string;
    /**
    * Display name of the Authenticator
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#name Authenticator#name}
    */
    readonly name: string;
    /**
    * The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_auth_port Authenticator#provider_auth_port}
    */
    readonly providerAuthPort?: number;
    /**
    * The Duo Security API hostname
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_host Authenticator#provider_host}
    */
    readonly providerHost?: string;
    /**
    * Server host name or IP address
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_hostname Authenticator#provider_hostname}
    */
    readonly providerHostname?: string;
    /**
    * The Duo Security integration key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_integration_key Authenticator#provider_integration_key}
    */
    readonly providerIntegrationKey?: string;
    /**
    * Provider in JSON format
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_json Authenticator#provider_json}
    */
    readonly providerJson?: string;
    /**
    * The Duo Security secret key
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_secret_key Authenticator#provider_secret_key}
    */
    readonly providerSecretKey?: string;
    /**
    * An authentication key that must be defined when the RADIUS server is configured, and must be the same on both the RADIUS client and server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_shared_secret Authenticator#provider_shared_secret}
    */
    readonly providerSharedSecret?: string;
    /**
    * Format expected by the provider
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#provider_user_name_template Authenticator#provider_user_name_template}
    */
    readonly providerUserNameTemplate?: string;
    /**
    * Authenticator settings in JSON format
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#settings Authenticator#settings}
    */
    readonly settings?: string;
    /**
    * Authenticator status: ACTIVE or INACTIVE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#status Authenticator#status}
    */
    readonly status?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator okta_authenticator}
*/
export declare class Authenticator extends cdktf.TerraformResource {
    static readonly tfResourceType = "okta_authenticator";
    /**
    * Generates CDKTF code for importing a Authenticator resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Authenticator to import
    * @param importFromId The id of the existing Authenticator that should be imported. Refer to the {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Authenticator to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/okta/okta/4.6.0/docs/resources/authenticator okta_authenticator} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AuthenticatorConfig
    */
    constructor(scope: Construct, id: string, config: AuthenticatorConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _providerAuthPort?;
    get providerAuthPort(): number;
    set providerAuthPort(value: number);
    resetProviderAuthPort(): void;
    get providerAuthPortInput(): number | undefined;
    private _providerHost?;
    get providerHost(): string;
    set providerHost(value: string);
    resetProviderHost(): void;
    get providerHostInput(): string | undefined;
    private _providerHostname?;
    get providerHostname(): string;
    set providerHostname(value: string);
    resetProviderHostname(): void;
    get providerHostnameInput(): string | undefined;
    get providerInstanceId(): string;
    private _providerIntegrationKey?;
    get providerIntegrationKey(): string;
    set providerIntegrationKey(value: string);
    resetProviderIntegrationKey(): void;
    get providerIntegrationKeyInput(): string | undefined;
    private _providerJson?;
    get providerJson(): string;
    set providerJson(value: string);
    resetProviderJson(): void;
    get providerJsonInput(): string | undefined;
    private _providerSecretKey?;
    get providerSecretKey(): string;
    set providerSecretKey(value: string);
    resetProviderSecretKey(): void;
    get providerSecretKeyInput(): string | undefined;
    private _providerSharedSecret?;
    get providerSharedSecret(): string;
    set providerSharedSecret(value: string);
    resetProviderSharedSecret(): void;
    get providerSharedSecretInput(): string | undefined;
    get providerType(): string;
    private _providerUserNameTemplate?;
    get providerUserNameTemplate(): string;
    set providerUserNameTemplate(value: string);
    resetProviderUserNameTemplate(): void;
    get providerUserNameTemplateInput(): string | undefined;
    private _settings?;
    get settings(): string;
    set settings(value: string);
    resetSettings(): void;
    get settingsInput(): string | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    get type(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
